==> kdebindings-2.2.2.tar.bz2: kdebindings-2.2.2/kdejava/koala/org/kde/koala/KEdFindSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KEdFind} emits these signals */
public interface KEdFindSignals {

/**  
 The User3 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser3} is not replaced.
     
*/
	void user3Clicked();
	void destroyed();

/**  
 The Yes button was pressed. This signal is only emitted if
 {@link KEdFind#slotYes} is not replaced.
     
*/
	void yesClicked();
	void done();

/**  
 The Help button was pressed. This signal is only emitted if
 {@link KEdFind#slotHelp} is not replaced.
     
*/
	void helpClicked();

/**  
 The Apply button was pressed. This signal is only emitted if
 {@link KEdFind#slotApply} is not replaced.
     
*/
	void applyClicked();

/**  
 The Default button was pressed. This signal is only emitted if
 {@link KEdFind#slotDefault} is not replaced.
     
*/
	void defaultClicked();

/**  
 The Try button was pressed. This signal is only emitted if
 {@link KEdFind#slotTry} is not replaced.
     
*/
	void tryClicked();

/**  
 The No button was pressed. This signal is only emitted if
 {@link KEdFind#slotNo} is not replaced.
     
*/
	void noClicked();

/**  
 The detailsWidget is about to get shown. This is your last chance
 to call setDetailsWidget if you haven't done so yet.
     
*/
	void aboutToShowDetails();

/**  
 The Cancel button was pressed. This signal is only emitted if
 {@link KEdFind#slotCancel} is not replaced.
     
*/
	void cancelClicked();
	void search();

/**  
 Do not use this signal. Is is kept for compatibility reasons.
 Use {@link KEdFind#applyClicked} instead.
     
*/
	void apply();

/** 
 The dialog has finished.

 A dialog emits finished after a user clicks a button that ends
 the dialog.

 This signal is also emitted when you call {@link KEdFind#hide}

 If you have stored a pointer to the
 dialog do <em>not</em> try to delete the pointer in the slot that is
 connected to this signal.

 You should use {@link KEdFind#delayedDestruct} instead.
     
*/
	void finished();

/**  
 The background tile has changed.
     
*/
	void backgroundChanged();

/**  
 The User1 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser1} is not replaced.
     
*/
	void user1Clicked();

/** 
 Emitted when the margin size and/or spacing size 
 have changed.

 Use {@link KEdFind#marginHint} and  {@link KEdFind#spacingHint} in your slot
 to get the new values.
     
*/
	void layoutHintChanged();

/**  
 The Close button was pressed. This signal is only emitted if
 {@link KEdFind#slotClose} is not replaced.
     
*/
	void closeClicked();

/**  
 The OK button was pressed. This signal is only emitted if
 {@link KEdFind#slotOk} is not replaced.
     
*/
	void okClicked();

/** 
 The dialog is about to be hidden.

 A dialog is hidden after a user clicks a button that ends
 the dialog or when the user switches to another desktop or
 minimizes the dialog.
     
*/
	void hidden();

/**  
 The User2 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser2} is not replaced.
     
*/
	void user2Clicked();
}

==> kdebindings-3.0.1.tar.bz2: kdebindings-3.0.1/kdejava/koala/org/kde/koala/KEdFindSignals.java <==
package org.kde.koala;
import org.kde.qt.*;


/** {@link KEdFind} emits these signals */
public interface KEdFindSignals {

/** 
 The User3 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser3} is not replaced.
     
*/
	void user3Clicked();
	void destroyed( QObject obj );

/** 
 The Yes button was pressed. This signal is only emitted if
 {@link KEdFind#slotYes} is not replaced.
     
*/
	void yesClicked();
	void done();

/** 
 The Help button was pressed. This signal is only emitted if
 {@link KEdFind#slotHelp} is not replaced.
     
*/
	void helpClicked();

/** 
 The Apply button was pressed. This signal is only emitted if
 {@link KEdFind#slotApply} is not replaced.
     
*/
	void applyClicked();

/** 
 The Default button was pressed. This signal is only emitted if
 {@link KEdFind#slotDefault} is not replaced.
     
*/
	void defaultClicked();

/** 
 The Try button was pressed. This signal is only emitted if
 {@link KEdFind#slotTry} is not replaced.
     
*/
	void tryClicked();

/** 
 The No button was pressed. This signal is only emitted if
 {@link KEdFind#slotNo} is not replaced.
     
*/
	void noClicked();

/** 
 The detailsWidget is about to get shown. This is your last chance
 to call setDetailsWidget if you haven't done so yet.
     
*/
	void aboutToShowDetails();

/** 
 The Cancel button was pressed. This signal is only emitted if
 {@link KEdFind#slotCancel} is not replaced.
     
*/
	void cancelClicked();
	void search();

/** 
 Do not use this signal. Is is kept for compatibility reasons.
 Use {@link KEdFind#applyClicked} instead.
     
*/
	void apply();

/** 
 The dialog has finished.

 A dialog emits finished after a user clicks a button that ends
 the dialog.

 This signal is also emitted when you call {@link KEdFind#hide}

 If you have stored a pointer to the
 dialog do <em>not</em> try to delete the pointer in the slot that is
 connected to this signal.

 You should use {@link KEdFind#delayedDestruct} instead.
     
*/
	void finished();

/** 
 The background tile has changed.
     
*/
	void backgroundChanged();

/** 
 The User1 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser1} is not replaced.
     
*/
	void user1Clicked();

/** 
 Emitted when the margin size and/or spacing size 
 have changed.

 Use {@link KEdFind#marginHint} and  {@link KEdFind#spacingHint} in your slot
 to get the new values.
     
*/
	void layoutHintChanged();

/** 
 The Close button was pressed. This signal is only emitted if
 {@link KEdFind#slotClose} is not replaced.
     
*/
	void closeClicked();

/** 
 The OK button was pressed. This signal is only emitted if
 {@link KEdFind#slotOk} is not replaced.
     
*/
	void okClicked();

/** 
 The dialog is about to be hidden.

 A dialog is hidden after a user clicks a button that ends
 the dialog or when the user switches to another desktop or
 minimizes the dialog.
     
*/
	void hidden();

/** 
 The User2 button was pressed. This signal is only emitted if
 {@link KEdFind#slotUser2} is not replaced.
     
*/
	void user2Clicked();

/** 
 A page is about to be shown.
     
*/
	void aboutToShowPage( QWidget page );
}
